@@ -84,10 +84,12 @@ class IndexDb:
             self.load(vector=True)
         pnf = ParamInfo.build_from_name(name, param_level_types=self.param_types)
         if pnf is not None:
-            fs = self._select_fs(**pnf.make_filter())
+            fs = self._select_fs(
+                **pnf.make_filter(), _named_vector_param=(not pnf.scalar)
+            )
             if fs is not None:
                 pnf.update_meta(fs._db._first_index_row())
-                fs._param_info = pnf
+                fs._ds_param_info = pnf
                 return fs
         return None
 
@@ -101,31 +103,45 @@ class IndexDb:
         """
         LOG.debug(f"kwargs={kwargs}")
 
-        max_count = kwargs.pop("max_count", -1)
+        vector = kwargs.pop("_named_vector_param", False)
+        max_count = kwargs.pop("_max_count", -1)
 
         # print(f"kwargs={kwargs}")
         # LOG.debug(f"blocks={self.blocks}")
         dims = self._make_dims(kwargs)
+
+        # We can only have a vector param when the fs["wind"]-like operator is
+        # invoked and we deduce the shortName from the specified name
+        if vector:
+            short_name = dims.get("shortName", [])
+            if isinstance(short_name, list):
+                assert len(short_name) == 1
+
         # print(f"dims={dims}")
-        self.load(keys=list(dims.keys()), vector=("wind" in dims.get("shortName", "")))
-        db, fs = self._get_fields(dims, max_count=max_count)
-        # for f in r:
-        #     fs.append(f)
+        self.load(keys=list(dims.keys()), vector=vector)
+
+        db, fs = self._get_fields(dims, max_count=max_count, vector=vector)
         fs._db = db
-        # fs._param_info = self.get_param_info()
         # LOG.debug(f"fs={fs}")
         # print(f"blocks={fs._db.blocks}")
         return fs
 
-    def _get_fields(self, dims, max_count=-1):
+    def _get_fields(self, dims, max_count=-1, vector=False):
 
         res = self.fieldset_class()
         dfs = {}
         LOG.debug(f"dims={dims}")
-        for key in self.blocks.keys():
-            self._get_fields_for_block(key, dims, dfs, res, max_count)
-            if max_count != -1 and len(res) >= max_count:
-                break
+
+        name_filter = "shortName" in dims or "paramId" in dims
+        if not vector and name_filter:
+            # in this case filtering can only be done on the scalar block
+            if "scalar" in self.blocks.keys():
+                self._get_fields_for_block("scalar", dims, dfs, res, max_count)
+        else:
+            for key in self.blocks.keys():
+                self._get_fields_for_block(key, dims, dfs, res, max_count)
+                if max_count != -1 and len(res) >= max_count:
+                    break
 
         # LOG.debug(f"len_res={len(res)}")
         # LOG.debug(f"dfs={dfs}")
@@ -211,10 +227,12 @@ class IndexDb:
             return df_res
 
     def _get_fields_for_block(self, key, dims, dfs, res, max_count):
+        # print(f"key={key} dims={dims}")
         # LOG.debug(f"block={self.blocks[key]}")
         if self.blocks[key] is None:
             self._load_block(key)
         df = self._filter_df(df=self.blocks[key], dims=dims)
+        # print(f"df={df}")
         # LOG.debug(f"df={df}")
         if df is not None and not df.empty:
             df_fs = self._extract_fields(df, res, max_count)
@@ -226,7 +244,10 @@ class IndexDb:
     def _make_param_info(self):
         m = self._first_index_row()
         if m:
-            pnf = ParamInfo(m["shortName"], meta=dict(m))
+            name = m["shortName"]
+            pnf = ParamInfo(
+                name, meta=dict(m), scalar=not name in ParamInfo.VECTOR_NAMES
+            )
             return pnf
         return None
 
@@ -269,15 +290,12 @@ class IndexDb:
             # print(self._param_types)
         return self._param_types
 
-    def unique(self, key, param=None):
-        r = set()
-        if param is not None:
-            for _, v in self.blocks.items():
-                df_res = v.query(f"shortName = {param}")
-        else:
-            for _, v in self.blocks.items():
-                r.update(v[key].unique().tolist())
-        return sorted(list(r))
+    def unique(self, key):
+        self.load([key])
+        for _, v in self.blocks.items():
+            if key in v.columns:
+                return list(v[key].unique())
+        return []
 
     @property
     def param_meta(self):
@@ -354,11 +372,11 @@ class FieldsetDb(IndexDb):
             return None
 
         # print(f"comp_num={comp_num}")
-
         idx = [[] for k in range(comp_num)]
         comp_lst = list(range(comp_num))
         cnt = 0
         for row in df.itertuples():
+            # print(f"{row}")
             if max_count == -1 or len(fs) < max_count:
                 for comp in comp_lst:
                     fs.append(self.fs[row[-1 - (comp_num - comp - 1)]])
@@ -377,6 +395,24 @@ class FieldsetDb(IndexDb):
             df[f"_msgIndex{k+1}"] = v
         return df
 
+    def _extract_scalar_fields(self, df):
+        if df.empty:
+            return None, None
+
+        assert "_msgIndex1" in df.columns
+        assert "_msgIndex2" not in df.columns
+        assert "_msgIndex3" not in df.columns
+
+        fs = self.fieldset_class()
+        for row in df.itertuples():
+            fs.append(self.fs[row[-1]])
+
+        assert len(fs) == len(df.index)
+        # generate a new dataframe
+        df = df.copy()
+        df["_msgIndex1"] = list(range(len(df.index)))
+        return df, fs
+
     def _clone(self):
         db = FieldsetDb(self.name, label=self.label, regrid_from=self.regrid_from)
 
@@ -393,18 +429,6 @@ class FieldsetDb(IndexDb):
         else:
             return ParamInfo.build_from_fieldset(fs)
 
-    def unique(self, key):
-        r = list()
-        for _, v in self.blocks.items():
-            r.extend(v[key].unique().tolist())
-        return list(dict.fromkeys(r))
-
-        # r = set()
-        # for _, v in self.blocks.items():
-        #     r.update(v[key].unique().tolist())
-        # # return sorted(list(r))
-        # return r
-
     def ls(self, extra_keys=None, filter=None, no_print=False):
         default_keys = [
             "centre",
@@ -439,7 +463,7 @@ class FieldsetDb(IndexDb):
         keys = list(ls_keys)
         keys.append("_msgIndex1")
         df = df[keys]
-        df = df.sort_values(by="_msgIndex1")
+        df = df.sort_values("_msgIndex1")
         df = df.rename(columns={"_msgIndex1": "Message"})
         df = df.set_index("Message")
 
@@ -462,43 +486,81 @@ class FieldsetDb(IndexDb):
             print(df)
         return df
 
-    def speed(self):
-        r = mv.Fieldset()
-        if len(self.fs) >= 2:
-            for i in range(len(self.fs) // 2):
-                r.append(mv.sqrt(self.fs[2 * i] ** 2 + self.fs[2 * i + 1] ** 2))
-            pnf = self.fs.param_info
-            LOG.debug(f"speed pnf={pnf}")
-            param_id = 10
-            if pnf is not None:
-                param_ids = {"wind10m": 207, "wind": 10}
-                param_id = param_ids.get(pnf.name, param_id)
-            r = r.grib_set_long(["paramId", param_id])
-            r._db = FieldsetDb(r, label=self.label)
-            r._db.load()
-        return r
-
-    def deacc(self, skip_first=False):
-        if len(self.fs) > 1:
-            self.load()
-            step = self.unique("step")
-            if step:
-                v = self.select(step=step[0])
-                if not skip_first:
-                    r = v * 0
+    def sort(self, *args, **kwargs):
+        # handle arguments
+        keys = []
+        asc = None
+        if len(args) >= 1:
+            keys = args[0]
+            if not isinstance(keys, list):
+                keys = [keys]
+            # optional positional argument - we only implement it to provide
+            # backward compability for the sort() Macro function
+            if len(args) == 2:
+                asc = args[1]
+                if isinstance(asc, list):
+                    if len(keys) != len(asc):
+                        raise ValueError(
+                            f"sort(): when order is specified as a list it must have the same number of elements as keys! {len(keys)} != {len(asc)}"
+                        )
+                    for i, v in enumerate(asc):
+                        if v not in [">", "<"]:
+                            raise ValueError(
+                                f"sort(): invalid value={v} in order! Only "
+                                > " and "
+                                < " are allowed!"
+                            )
+                        asc[i] = True if v == "<" else False
                 else:
-                    r = mv.Fieldset()
-                for i in range(1, len(step)):
-                    v_next = self.select(step=step[i])
-                    r.append(v_next - v)
-                    v = v_next
-                r = r.grib_set_long(["generatingProcessIdentifier", 148])
-                r._db = FieldsetDb(
-                    r, label=self.label, mapped_params=self.mapped_params
+                    if asc not in [">", "<"]:
+                        raise ValueError(
+                            f"sort(): invalid value={asc} in order! Only "
+                            > " and "
+                            < " are allowed!"
+                        )
+                    asc = True if asc == "<" else False
+
+        if "ascending" in kwargs:
+            if asc is not None:
+                raise ValueError(
+                    "sort(): cannot take both a second positional argument and the ascending keyword argument!"
                 )
-                r._db.load()
-                return r
-        return None
+            asc = kwargs.pop("ascending")
+
+        if asc is None:
+            asc = True
+
+        if len(keys) == 0:
+            keys = self.indexer.DEFAULT_SORT_KEYS
+
+        # print(f"keys={keys} asc={asc}")
+
+        # get metadata
+        self.load(keys=keys, vector=False)
+
+        scalar_df = self.blocks.get("scalar")
+        if scalar_df is not None:
+            dfs = self.indexer._sort_dataframe(scalar_df, columns=keys, ascending=asc)
+            # print(f"dfs={dfs.iloc[0:5]}")
+            # print(dfs)
+
+            df, res = self._extract_scalar_fields(dfs)
+            # print(f"df={df.iloc[0:5]}")
+
+            # LOG.debug(f"len_res={len(res)}")
+            # LOG.debug(f"dfs={dfs}")
+            # LOG.debug(f"res={res}")
+            c = FieldsetDb(
+                res,
+                name=self.name,
+                blocks={"scalar": df},
+                label=self.label,
+                mapped_params=self.mapped_params,
+                regrid_from=self.regrid_from,
+            )
+
+            res._db = c
+        return res
 
     def get_longname_and_units(self, short_name, param_id):
         # The name and units keys are not included in the default set of keys for the
@@ -510,7 +572,7 @@ class FieldsetDb(IndexDb):
         if param_id:
             a["paramId"] = param_id
         if a:
-            a["max_count"] = 1
+            a["_max_count"] = 1
             r = self.select(**a)
             if r is not None and len(r) > 0:
                 md = r[0].grib_get(["name", "units"])
