@@ -192,6 +192,31 @@ def _y_min(data):
     return min([min(d) for d in data])
 
 
+def _scale_data(data, style_db="param", plot_type="map"):
+    if isinstance(data, mv.Fieldset):
+        scaler = mv.style.get_db(name=style_db).units_scaler(data, plot_type=plot_type)
+        if scaler is not None:
+            return scaler.scale_value(data)
+    return data
+
+
+def _scale_xs(name, data):
+    if isinstance(data, mv.Fieldset):
+        scaler = None
+        for f in data:
+            if f.grib_get_string("shortName") != "lnsp":
+                scaler = mv.style.get_db(name="param").units_scaler(f, plot_type="xs")
+        if scaler is not None:
+            r = mv.Fieldset()
+            for f in data:
+                if f.grib_get_string("shortName") != "lnsp":
+                    r.append(scaler.scale_value(f))
+                else:
+                    r.append(f)
+            return r
+    return data
+
+
 def plot_maps(
     *args,
     layout=None,
@@ -254,6 +279,8 @@ def plot_maps(
                         data = data[frame]
                     else:
                         data = data[2 * frame : 2 * frame + 2]
+
+                data = _scale_data(data, style_db="param", plot_type="map")
             elif isinstance(data, Track):
                 data = data.build(style=vd)
 
@@ -471,14 +498,7 @@ def plot_xs(
             desc.append(xs_d)
         else:
             if param_info is not None:
-                if param_info.name == "t":
-                    data = data - 273.16
-                elif param_info.name == "pv":
-                    data = data * 1e6
-                elif param_info.name == "q":
-                    data = data * 1e3
-                elif param_info.name in ["vo", "absv"]:
-                    data = data * 1e5
+                data = _scale_xs(param_info.name, data)
             desc.append(data)
 
         if vd:
@@ -955,3 +975,70 @@ def plot_cdf(*args, location=None, title_font_size=0.4, x_range=None):
     desc.append(legend)
 
     mv.plot(desc, animate=False)
+
+
+def plot_xs_avg(
+    *args,
+    area=None,
+    direction="ew",
+    vertical_scaling="linear",
+    title_font_size=0.3,
+    legend_font_size=0.2,
+    axis_font_size=0.3,
+    animate="auto",
+):
+    """
+    Plot average cross section
+    """
+
+    if area is None:
+        area = [90, -180, -90, 180]
+
+    assert isinstance(args[0], mv.Fieldset)
+    layers = _make_layers(*args, form_layout=False)
+    assert len(layers) > 0
+
+    view = Layout().build_xs_avg(
+        area=area,
+        direction=direction,
+        bottom_level=1000,
+        top_level=50,
+        vertical_scaling=vertical_scaling,
+        axis_label_height=axis_font_size,
+    )
+
+    # the plot description
+    desc = []
+
+    title = Title(font_size=title_font_size)
+    data_items = []
+
+    # build cross section plot
+    desc.append(view)
+    for layer in layers:
+        data = layer["data"]
+
+        vd = _make_visdef(data, layer["vd"], plot_type="xs")
+        param_info = data.ds_param_info
+        # print(f"param_info={param_info}")
+        data_items.append(data)
+        # print(f"data={len(data)}")
+
+        if param_info is not None:
+            data = _scale_xs(param_info.name, data)
+        desc.append(data)
+
+        if vd:
+            desc.extend(vd)
+        # print(f"vd={vd}")
+
+    t = title.build_xs(data_items)
+    desc.append(t)
+
+    legend = mv.mlegend(legend_text_font_size=legend_font_size)
+    desc.append(legend)
+    desc.append(t)
+
+    LOG.debug(f"desc={desc}")
+
+    return mv.plot(desc, animate=animate)
